@@ -1,10 +1,21 @@
 import logging
+import os
 import shutil
+import stat
 import subprocess
 from pathlib import Path
 
 import toml
-from glom import assign
+from glom import assign, delete, glom
+
+
+def _remove_readonly(func, path, _):
+    os.chmod(path, stat.S_IWRITE)
+    func(path)
+
+
+def _remove_git(path: Path):
+    shutil.rmtree(path, onerror=_remove_readonly)
 
 
 def create(name: str):
@@ -27,20 +38,25 @@ def create(name: str):
 
     project_path = Path(dst)
     pyproject_file = project_path / 'pyproject.toml'
-    data = toml.load(pyproject_file)
+
+    with pyproject_file.open('r', encoding='utf-8') as f:
+        data = toml.load(f)
+
     assign(data, 'project.name', name)
+    value = glom(data, "project.scripts.pyside_template")
+    delete(data, "project.scripts.pyside_template")
+    assign(data, f'project.scripts.{name}', value)
+
     with pyproject_file.open('w', encoding='utf-8') as f:
         toml.dump(data, f)
 
     git_dir = project_path / '.git'
-    shutil.rmtree(git_dir)
+    _remove_git(git_dir)
 
-    subprocess.run(
-        [
-            'git',
-            'init'
-        ],
+    subprocess.run([
+        'git',
+        'init'],
         cwd=project_path
     )
 
-    logging.info(f"Project {name} created successfully.")
+    logging.info(f"Project {name} created successfully")
